Glossary
========

.. glossary::
   :sorted:

   cartesian coordinates
      The "standard" coordinate system that (in 2D) uses two variables :math:`(x, y)`
      to address a point in space. Can be thought of as going
      *"along the corridor and up the stairs"*. See :ref:`math_cartesian_coordinates`

   polar coordinates
      An alternate coordinate system that (in 2D) uses two variables :math:`(r, \theta)`
      to address a point in space. Useful for curves and circular objects.
      See :ref:`math_polar_coordinates`

   linting
      Linting in software development is the process of running one or more tools
      against a codebase that search for potential issues. Examples include undefined
      variables or enforcing stylistic conventions such as line length.

   linear interpolation
      TBW

   transpose
       Transposing a matrix is the act of flipping the matrix around its principal
       diagonal. *All the columns become rows and the rows become columns*.
